package com.zhyc.module.produce.breed.service;

import java.util.List;
import com.zhyc.module.produce.breed.domain.ScDryMilk;

/**
 * 干奶记录Service接口
 * * @author ruoyi
 * @date 2025-07-15
 */
public interface IScDryMilkService
{
    /**
     * 查询干奶记录
     * * @param id 干奶记录主键
     * @return 干奶记录
     */
    public ScDryMilk selectScDryMilkById(Long id);

    /**
     * 查询干奶记录列表
     * * @param scDryMilk 干奶记录
     * @return 干奶记录集合
     */
    public List<ScDryMilk> selectScDryMilkList(ScDryMilk scDryMilk);

    /**
     * 新增干奶记录
     * * @param scDryMilk 干奶记录
     * @return 结果
     */
    public int insertScDryMilk(ScDryMilk scDryMilk);

    /**
     * 修改干奶记录
     * * @param scDryMilk 干奶记录
     * @return 结果
     */
    public int updateScDryMilk(ScDryMilk scDryMilk);

    /**
     * 批量删除干奶记录
     * * @param ids 需要删除的干奶记录主键集合
     * @return 结果
     */
    public int deleteScDryMilkByIds(Long[] ids);

    /**
     * 删除干奶记录信息
     * * @param id 干奶记录主键
     * @return 结果
     */
    public int deleteScDryMilkById(Long id);

    /**
     * 根据耳号查询羊只ID
     */
    public Long selectSheepIdByManageTags(String manageTags);

    /**
     * 远程搜索耳号列表
     */
    public List<String> selectSheepEarNumberList(String query);

    /**
     * 远程搜索技术员列表
     */
    public List<String> selectTechnicianList(String query);
}